# Facets Attachment Display

## Overview

The Facets Attachment Display module extends the [Facets](https://www.drupal.org/project/facets) and [Search API](https://www.drupal.org/project/search_api) modules to allow Views attachment displays to be used as facet sources. This enables you to add facets to search results that are displayed using Views attachments.

In standard Drupal setups, facets can only be associated with main Views displays (pages, blocks, etc.), but not with attachment displays. This module bridges that gap, making attachment displays valid facet sources in the Search API ecosystem.

## Use Cases

This module is particularly useful when:

- You have a complex search interface with multiple result sections
- You're using Views attachments to display different aspects of search results
- You want to apply facets to these attachment displays
- You need to filter attachment display results independently

## Requirements

- Drupal core 11.x
- [Search API](https://www.drupal.org/project/search_api) module
- [Facets](https://www.drupal.org/project/facets) module
- [Views](https://www.drupal.org/project/views) module (included in Drupal core)

## Installation

1. Download and install the module using Composer:
   ```
   composer require drupal/facets_attachment_display
   ```

   Or manually download and place it in the `/modules` directory.

2. Enable the module via Drush:
   ```
   drush en facets_attachment_display
   ```

   Or through the Drupal admin interface at `/admin/modules`.

## How It Works

The module works by:

1. Registering a new Search API display plugin type (`views_attachment`) by cloning and modifying the existing `views_display` plugin definition.

2. Implementing `hook_views_pre_view()` to detect when a Views attachment display is being rendered, and registering it as a Search API display if it's attached to a display that uses Search API.

3. Providing a custom `ViewsAttachment` display plugin that extends the Search API `ViewsDisplayBase` class, with special handling for attachment displays.

4. Ensuring that attachment displays are properly recognized as being rendered in the current request, and providing path information based on the parent display.

## Usage

### Setting Up a View with Attachment Display

1. Create a View that uses a Search API index as its base.
2. Add a main display (page, block, etc.) that will serve as the parent for your attachment.
3. Add an attachment display to your view.
4. Configure the attachment display to be attached to your main display.
5. Configure both displays to use the Search API query type.

### Creating Facets for the Attachment Display

1. Go to the Facets administration page (`/admin/config/search/facets`).
2. Click "Add facet".
3. In the "Facet source" dropdown, you should now see your attachment display listed with the format: `Views attachment: [view_name]__[display_id]`.
4. Select the appropriate facet source and configure your facet as needed.
5. Place the facet block in your desired region.

### Troubleshooting

If your attachment display is not appearing as a facet source:

- Ensure both the parent display and the attachment display use the Search API query type.
- Verify that the attachment display is properly configured to be attached to a main display.
- Clear the Drupal cache to ensure all plugin definitions are refreshed.

## Technical Details

The module implements two main hooks:

1. `hook_search_api_display_info_alter()`: Creates a new display plugin type for Views attachments.
2. `hook_views_pre_view()`: Detects and registers attachment displays as Search API displays.

The custom `ViewsAttachment` plugin class handles the special requirements of attachment displays, particularly:

- Always reporting that it is rendered in the current request (since attachments are always rendered with their parent).
- Determining the correct path by looking at the parent display.
